
#global         bootstrap   1
%global         build_doc   1

Summary:        GIO-based library for file manager-like programs
Name:           libfm
Version:        1.3.2
Release:        2%{?dist}
License:        GPLv2+
URL:            http://pcmanfm.sourceforge.net/
Source0:        https://github.com/lxde/libfm/archive/refs/tags/%{version}.tar.gz
Patch3000:      libfm-1.3.2-0001-fm_config_load_from_key_file-don-t-replace-string-va.patch
Patch3001:      libfm-1.3.0.2-moduledir-gtkspecific-v03.patch

BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.26.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.27.0
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(libexif)

%if ! 0%{?bootstrap}
BuildRequires:  menu-cache-devel >= 0.3.2
%endif

BuildRequires:  make
BuildRequires:  gcc
BuildRequires:  gettext
BuildRequires:  intltool
BuildRequires:  desktop-file-utils
BuildRequires:  gtk-doc
BuildRequires:  libxslt
BuildRequires:  vala
BuildRequires:  automake
BuildRequires:  libtool



%description
LibFM is a GIO-based library used to develop file manager-like programs. It is
developed as the core of next generation PCManFM and takes care of all file-
related operations such as copy & paste, drag & drop, file associations or 
thumbnails support. By utilizing glib/gio and gvfs, libfm can access remote 
file systems supported by gvfs.

This package contains the generic non-gui functions of libfm.

%package        gtk
Summary:        File manager-related GTK+ widgets of %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       gvfs

%description    gtk
libfm is a GIO-based library used to develop file manager-like programs. It is
developed as the core of next generation PCManFM and takes care of all file-
related operations such as copy & paste, drag & drop, file associations or 
thumbnail support. By utilizing glib/gio and gvfs, libfm can access remote 
file systems supported by gvfs.

This package provides useful file manager-related GTK+ 3 widgets.

%package        gtk-utils
Summary:        GTK+ related utility package for %{name}
Requires:       %{name}-gtk = %{version}-%{release}
Provides:       lxshortcut = %{version}-%{release}
Provides:       lxshortcut = %{version}-%{release}

%description    gtk-utils
This package contains some GTK+ related utility files for
%{name}.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package        gtk-devel-common
Summary:        Common Development files for %{name}-gtk
Requires:       %{name}-devel = %{version}-%{release}
BuildArch:		noarch

%description    gtk-devel-common
The %{name}-gtk-devel package contains common header files for
developing applications that use %{name}-gtk.

%package        gtk-devel
Summary:        Development files for %{name}-gtk
Requires:       %{name}-gtk = %{version}-%{release}
Requires:       %{name}-gtk-devel-common = %{version}-%{release}

%description    gtk-devel
The %{name}-gtk-devel package contains libraries files for
developing applications that use %{name}-gtk.

%package        devel-docs
Summary:        Development documation for %{name}

%description    devel-docs
This package containg development documentation files for %{name}.



%prep
%autosetup -p1



%build
bash autogen.sh
sed -i.libdir_syssearch -e '/sys_lib_dlsearch_path_spec/s|/usr/lib |/usr/lib /usr/lib64 /lib /lib64 |' configure

%configure \
%if 0%{?bootstrap}
	    --with-extra-only \
%endif
	    --enable-gtk-doc \
	    --enable-udisks \
	    --with-gtk=3 \
	    --disable-demo \
	    --disable-silent-rules \
	    --disable-static

make -C po -j1 GMSGFMT="msgfmt --statistics"
%make_build -k



%install
%make_install
find %{buildroot} -name '*.la' -exec rm -f {} ';'

%if ! 0%{?bootstrap}
desktop-file-validate %{buildroot}/%{_datadir}/applications/*.desktop
( %find_lang %{name})
%endif

echo '%%defattr(-,root,root,-)' > base-header.files
echo '%%defattr(-,root,root,-)' > gtk-header.files

for f in %{buildroot}%_includedir/%name-1.0/*.h
do
  bf=$(basename $f)
  for dir in actions base job extra .
  do
    if [ -f src/$dir/$bf ]
    then
	echo %_includedir/%name-1.0/$bf >> base-header.files
    fi
  done
  for dir in gtk
  do
    if [ -f src/$dir/$bf ]
    then
	echo %_includedir/%name-1.0/$bf >> gtk-header.files
    fi
  done
done

/usr/lib/rpm/check-rpaths



%check
make check



%pre devel
if [ -d %{_includedir}/libfm ] ; then
  rm -rf %{_includedir}/libfm
fi



%if 0%{?bootstrap}
%files
%else
%files -f %{name}.lang
%endif
%license COPYING
%doc AUTHORS NEWS README
%{_libdir}/%{name}-extra.so.4*

%if ! 0%{?bootstrap}
%{_libdir}/%{name}.so.4*
%{_libdir}/libfm/modules/vfs-*.so
%dir %{_sysconfdir}/xdg/libfm/
%config(noreplace) %{_sysconfdir}/xdg/libfm/libfm.conf
%{_datadir}/%{name}/
%dir %{_libdir}/libfm
%dir %{_libdir}/libfm/modules
%{_datadir}/mime/packages/libfm.xml
%endif


%if ! 0%{?bootstrap}
%files gtk
%{_libdir}/%{name}-gtk3.so.4*
%{_libdir}/libfm/modules/gtk3/


%files gtk-utils
%{_bindir}/libfm-pref-apps
%{_bindir}/lxshortcut
%{_mandir}/man1/libfm-pref-apps.1.*
%{_mandir}/man1/lxshortcut.1.*
%{_datadir}/applications/libfm-pref-apps.desktop
%{_datadir}/applications/lxshortcut.desktop
%endif


%files devel -f base-header.files
%doc TODO
%{_includedir}/libfm
%dir %{_includedir}/libfm-1.0/

%if ! 0%{?bootstrap}
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/libfm.pc
%endif
%{_libdir}/%{name}-extra.so
%{_libdir}/pkgconfig/libfm-extra.pc


%if ! 0%{?bootstrap}
%files gtk-devel-common -f gtk-header.files
%{_includedir}/libfm-1.0/fm-gtk.h


%files gtk-devel
%{_libdir}/%{name}-gtk3.so
%{_libdir}/pkgconfig/libfm-gtk3.pc


%if 0%{?build_doc}
%files devel-docs
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%{_datadir}/gtk-doc/html/%{name}
%endif
%endif



%changelog
* Wed Jan 17 2024 Zhao Zhen <jeremiazhao@tencent.com> - 1.3.2-2
- non-bootstrap building

* Thu Dec 28 2023 Chair <chairou@tencent.com> - 1.3.2-1
- Init